# ProvenanceResultResponseResult

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**error** | **bool** | A flag set to true if an error was encountered |
**error_msg** | **str** | An error message reported to users |
**input** | **object** |  |
**parameters** | [**ProvenanceResultResponseResultParameters**](ProvenanceResultResponseResultParameters.md) |  |
**report** | **list[object]** | A provenance check report |

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

